==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/GlobalVarNode.h <==
// public class soot.jimple.spark.pag.GlobalVarNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class aa8c58395ffee7ee soot_jimple_spark_pag_GlobalVarNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 8f994f8885f1a8b4 soot_jimple_spark_pag_ValNode
// @dep_class 50497b61bb8d76a8 soot_jimple_spark_pag_VarNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_VarNode

#include "soot/jimple/spark/pag/VarNode.h"

#ifndef _JC_soot_jimple_spark_pag_GlobalVarNode_H_
#define _JC_soot_jimple_spark_pag_GlobalVarNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_GlobalVarNode$sub_refs	_jc_soot_jimple_spark_pag_GlobalVarNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_GlobalVarNode$sub_nonrefs	_jc_soot_jimple_spark_pag_GlobalVarNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_GlobalVarNode$refs	_jc_soot_jimple_spark_pag_GlobalVarNode$refs;
typedef struct _jc_soot_jimple_spark_pag_GlobalVarNode$nonrefs	_jc_soot_jimple_spark_pag_GlobalVarNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_GlobalVarNode$object	_jc_soot_jimple_spark_pag_GlobalVarNode$object;

typedef const struct _jc_soot_jimple_spark_pag_GlobalVarNode$vmethods	_jc_soot_jimple_spark_pag_GlobalVarNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_GlobalVarNode$vtable	_jc_soot_jimple_spark_pag_GlobalVarNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_GlobalVarNode$vtype	_jc_soot_jimple_spark_pag_GlobalVarNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_GlobalVarNode$method$_init$b7621485bfe11727(_jc_env *, struct _jc_soot_jimple_spark_pag_GlobalVarNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_java_lang_Object$object *, struct _jc_soot_Type$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_GlobalVarNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_GlobalVarNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_GlobalVarNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_GlobalVarNode$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_GlobalVarNode$object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_GlobalVarNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_ValNode$vmethods	soot_jimple_spark_pag_ValNode;
	_jc_soot_jimple_spark_pag_VarNode$vmethods	soot_jimple_spark_pag_VarNode;
	_jc_soot_jimple_spark_pag_GlobalVarNode$vmethods	soot_jimple_spark_pag_GlobalVarNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_GlobalVarNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_GlobalVarNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_GlobalVarNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_GlobalVarNode$refs {
    _jc_soot_jimple_spark_pag_GlobalVarNode$sub_refs	soot_jimple_spark_pag_GlobalVarNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_refs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_ValNode$sub_refs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_GlobalVarNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_GlobalVarNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_nonrefs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_GlobalVarNode$sub_nonrefs	soot_jimple_spark_pag_GlobalVarNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_GlobalVarNode$object {
	_jc_soot_jimple_spark_pag_GlobalVarNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_GlobalVarNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_GlobalVarNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_GlobalVarNode$vtype _jc_soot_jimple_spark_pag_GlobalVarNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_GlobalVarNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_GlobalVarNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_GlobalVarNode_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/GlobalVarNode.h <==
// public class soot.jimple.spark.pag.GlobalVarNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class aa8c58395ffee7ee soot_jimple_spark_pag_GlobalVarNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 8f994f8885f1a8b4 soot_jimple_spark_pag_ValNode
// @dep_class 50497b61bb8d76a8 soot_jimple_spark_pag_VarNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_VarNode

#include "soot/jimple/spark/pag/VarNode.h"

#ifndef _JC_soot_jimple_spark_pag_GlobalVarNode_H_
#define _JC_soot_jimple_spark_pag_GlobalVarNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_GlobalVarNode$sub_refs	_jc_soot_jimple_spark_pag_GlobalVarNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_GlobalVarNode$sub_nonrefs	_jc_soot_jimple_spark_pag_GlobalVarNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_GlobalVarNode$refs	_jc_soot_jimple_spark_pag_GlobalVarNode$refs;
typedef struct _jc_soot_jimple_spark_pag_GlobalVarNode$nonrefs	_jc_soot_jimple_spark_pag_GlobalVarNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_GlobalVarNode$object	_jc_soot_jimple_spark_pag_GlobalVarNode$object;

typedef const struct _jc_soot_jimple_spark_pag_GlobalVarNode$vmethods	_jc_soot_jimple_spark_pag_GlobalVarNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_GlobalVarNode$vtable	_jc_soot_jimple_spark_pag_GlobalVarNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_GlobalVarNode$vtype	_jc_soot_jimple_spark_pag_GlobalVarNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_GlobalVarNode$method$_init$b7621485bfe11727(_jc_env *, struct _jc_soot_jimple_spark_pag_GlobalVarNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_java_lang_Object$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_GlobalVarNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_GlobalVarNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_GlobalVarNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_GlobalVarNode$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_GlobalVarNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_GlobalVarNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_ValNode$vmethods	soot_jimple_spark_pag_ValNode;
	_jc_soot_jimple_spark_pag_VarNode$vmethods	soot_jimple_spark_pag_VarNode;
	_jc_soot_jimple_spark_pag_GlobalVarNode$vmethods	soot_jimple_spark_pag_GlobalVarNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_GlobalVarNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_GlobalVarNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_GlobalVarNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_GlobalVarNode$refs {
    _jc_soot_jimple_spark_pag_GlobalVarNode$sub_refs	soot_jimple_spark_pag_GlobalVarNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_refs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_ValNode$sub_refs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_GlobalVarNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_GlobalVarNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_VarNode$sub_nonrefs	soot_jimple_spark_pag_VarNode;
    _jc_soot_jimple_spark_pag_GlobalVarNode$sub_nonrefs	soot_jimple_spark_pag_GlobalVarNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_GlobalVarNode$object {
	_jc_soot_jimple_spark_pag_GlobalVarNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_GlobalVarNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_GlobalVarNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_GlobalVarNode$vtype _jc_soot_jimple_spark_pag_GlobalVarNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_GlobalVarNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_GlobalVarNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_GlobalVarNode_H_ */
